@@ -4,7 +4,7 @@ from importlib.abc import Loader as _Loader
 from importlib.abc import MetaPathFinder as _MetaPathFinder
 
 from . import mask  # noqa
-from ._version import get_versions  # noqa
+from ._version import get_versions
 
 
 class replace:
@@ -110,7 +110,7 @@ def init(backend="suitesparse", blocking=False):
 def _init(backend_arg, blocking, automatic=False):
     global _init_params, backend, lib, ffi
 
-    passed_params = dict(backend=backend_arg, blocking=blocking, automatic=automatic)
+    passed_params = {"backend": backend_arg, "blocking": blocking, "automatic": automatic}
     if _init_params is not None:
         if blocking is None:
             passed_params["blocking"] = _init_params["blocking"]
@@ -186,7 +186,7 @@ class _GraphblasModuleFinder(_MetaPathFinder):
         if fullname in _NEEDS_OPERATOR and "operator" not in globals():
             _load("operator")
             name = fullname[7:]  # Trim "graphblas."
-            if name in globals():
+            if name in globals():  # pragma: no cover
                 # Make sure we execute the module only once
                 module = globals()[name]
                 spec = module.__spec__
@@ -195,14 +195,14 @@ class _GraphblasModuleFinder(_MetaPathFinder):
 
 
 class _SkipLoad(_Loader):
-    def __init__(self, module, orig_loader):
+    def __init__(self, module, orig_loader):  # pragma: no cover
         self.module = module
         self.orig_loader = orig_loader
 
-    def create_module(self, spec):
+    def create_module(self, spec):  # pragma: no cover
         return self.module
 
-    def exec_module(self, module):
+    def exec_module(self, module):  # pragma: no cover
         # Don't execute the module, but restore the original loader
         module.__spec__.loader = self.orig_loader
 
