@@ -176,8 +176,8 @@ def _check_mask(mask, output=None):
     if output is not None:
         from .vector import Vector
 
-        if type(output) is Vector and type(mask.mask) is not Vector:
-            raise TypeError(f"Mask object must be type Vector; got {type(mask.mask)}")
+        if type(output) is Vector and type(mask.parent) is not Vector:
+            raise TypeError(f"Mask object must be type Vector; got {type(mask.parent)}")
 
 
 class BaseType:
@@ -423,10 +423,14 @@ class BaseType:
 
         if input_mask is not None:
             raise TypeError("`input_mask` argument may only be used for extract")
-        if expr.op is not None and expr.op.opclass == "Aggregator":
+        elif expr.op is not None and expr.op.opclass == "Aggregator":
             updater = self(mask=mask, accum=accum, replace=replace)
             expr.op._new(updater, expr)
             return
+        elif expr.cfunc_name is None:  # Custom recipe
+            updater = self(mask=mask, accum=accum, replace=replace)
+            expr.args[-2](updater, *expr.args[-1])
+            return
 
         # Normalize mask and separate out complement and structural flags
         if mask is None:
@@ -540,9 +544,9 @@ class BaseExpression:
         self.bt = bt
         self.op = op
         if expr_repr is None:
-            if len(args) == 1:
+            if len(args) == 1 or cfunc_name is None and len(args) == 3:
                 expr_repr = "{0.name}.{method_name}({op})"
-            elif len(args) == 2:
+            elif len(args) == 2 or cfunc_name is None and len(args) == 4:
                 expr_repr = "{0.name}.{method_name}({1.name}, op={op})"
             else:  # pragma: no cover
                 raise ValueError(f"No default expr_repr for len(args) == {len(args)}")
@@ -573,6 +577,8 @@ class BaseExpression:
         if self.op is not None and self.op.opclass == "Aggregator":
             updater = output(mask=mask)
             self.op._new(updater, self)
+        elif self.cfunc_name is None:  # Custom recipe
+            self.args[-2](output(mask=mask), *self.args[-1])
         elif mask is None:
             output.update(self)
         else:
@@ -583,13 +589,15 @@ class BaseExpression:
     dup = new
 
     def _format_expr(self):
-        return self.expr_repr.format(*self.args, method_name=self.method_name, op=self.op)
+        args = self.args[:-2] if self.cfunc_name is None else self.args
+        return self.expr_repr.format(*args, method_name=self.method_name, op=self.op)
 
     def _format_expr_html(self):
         expr_repr = self.expr_repr.replace(".name", "._name_html").replace(
             "._expr_name", "._expr_name_html"
         )
-        return expr_repr.format(*self.args, method_name=self.method_name, op=self.op)
+        args = self.args[:-2] if self.cfunc_name is None else self.args
+        return expr_repr.format(*args, method_name=self.method_name, op=self.op)
 
     _expect_type = _expect_type
     _expect_op = _expect_op
