@@ -110,9 +110,9 @@ def test_unify_dtypes():
 
 def test_dtype_bad_comparison():
     with pytest.raises(TypeError):
-        dtypes.BOOL == object()
+        assert dtypes.BOOL == object()
     with pytest.raises(TypeError):
-        object() != dtypes.BOOL
+        assert object() != dtypes.BOOL
 
 
 def test_dtypes_match_numpy():
@@ -137,7 +137,7 @@ def test_pickle():
             assert val.np_type == val2.np_type
             assert val.name == val2.name
         else:
-            val == val2
+            assert val == val2
     s = pickle.dumps(dtypes._INDEX)
     val2 = pickle.loads(s)
     assert dtypes._INDEX == val2
@@ -170,7 +170,7 @@ def test_lt_dtypes():
     assert sorted(all_dtypes) == expected
     assert dtypes.BOOL < "FP32"
     with pytest.raises(TypeError):
-        dtypes.BOOL < 5
+        assert dtypes.BOOL < 5
 
 
 def test_bad_register():
@@ -188,3 +188,21 @@ def test_bad_register():
         dtypes.register_new("register_new", record_dtype)
     with pytest.raises(ValueError, match="name"):
         dtypes.register_new("UINT8", record_dtype)
+
+
+def test_auto_register():
+    n = np.random.randint(10, 64)
+    np_type = np.dtype(f"({n},)int16")
+    assert lookup_dtype(np_type).np_type == np_type
+
+
+def test_default_names():
+    from graphblas.dtypes import _default_name
+
+    assert _default_name(np.dtype([("x", np.int32), ("y", np.float64)], align=True)) == (
+        "{'x': INT32, 'y': FP64}"
+    )
+    assert _default_name(np.dtype("(29,)uint8")) == "UINT8[29]"
+    assert _default_name(np.dtype("(3,4)bool")) == "BOOL[3, 4]"
+    assert _default_name(np.dtype((np.dtype("(5,)float64"), (6,)))) == "FP64[5][6]"
+    assert _default_name(np.dtype("S5")) == "dtype('S5')"
