@@ -136,7 +136,7 @@ def test_unaryop_udf():
     def plus_one(x):
         return x + 1  # pragma: no cover
 
-    UnaryOp.register_new("plus_one", plus_one)
+    unary.register_new("plus_one", plus_one)
     assert hasattr(unary, "plus_one")
     assert unary.plus_one.orig_func is plus_one
     assert unary.plus_one[int].orig_func is plus_one
@@ -205,7 +205,7 @@ def test_binaryop_parameterized():
 
         return inner
 
-    op = BinaryOp.register_anonymous(plus_plus_x, parameterized=True)
+    op = binary.register_anonymous(plus_plus_x, parameterized=True)
     assert not op.is_positional
     assert op.monoid is None
     assert op(1).monoid is None
@@ -351,10 +351,10 @@ def test_semiring_parameterized():
     def plus_plus_x_identity(x=0):
         return -x
 
-    assert Semiring.register_anonymous(monoid.min, binary.plus).name == "min_plus"
+    assert semiring.register_anonymous(monoid.min, binary.plus).name == "min_plus"
 
     bin_op = BinaryOp.register_anonymous(plus_plus_x, parameterized=True)
-    mymonoid = Monoid.register_anonymous(bin_op, plus_plus_x_identity)
+    mymonoid = monoid.register_anonymous(bin_op, plus_plus_x_identity)
     # monoid and binaryop are both parameterized
     mysemiring = Semiring.register_anonymous(mymonoid, bin_op, name="my_semiring")
     assert not mysemiring.is_positional
@@ -1082,9 +1082,9 @@ def test_udt():
     assert int in udt_identity
     assert operator.get_typed_op(udt_identity, udt) is udt_identity[udt]
     with pytest.raises(ValueError):
-        "badname" in binary.eq
+        assert "badname" in binary.eq
     with pytest.raises(ValueError):
-        "badname" in udt_identity
+        assert "badname" in udt_identity
 
     def _udt_getx(val):
         return val["x"]  # pragma: no cover
@@ -1158,8 +1158,12 @@ def test_udt():
 
     assert binary.second[udt].type is udt
     assert binary.second[udt].type2 is udt
-    assert binary.second[udt, dtypes.INT8].type is udt
+    assert binary.second[udt, dtypes.INT8].type is dtypes.INT8  # ignore first arg
     assert binary.second[udt, dtypes.INT8].type2 is dtypes.INT8
+    assert semiring.any_second[udt, dtypes.INT8].type is dtypes.INT8  # ignore first arg
+    assert semiring.any_second[udt, dtypes.INT8].type2 is dtypes.INT8
+    assert binary.first[udt, dtypes.INT8].type is udt
+    assert binary.first[udt, dtypes.INT8].type2 is dtypes.INT8  # include second arg!
     assert monoid.any[udt].type2 is udt
 
 
@@ -1194,3 +1198,11 @@ def test_binaryop_commute_exists():
             missing.add(commutes_to.name)
     if missing:
         raise AssertionError("Missing binaryops: " + ", ".join(sorted(missing)))
+
+
+def test_binom():
+    v = Vector.from_values([0, 1, 2], [3, 4, 5])
+    result = v.apply(binary.binom, 2).new()
+    expected = Vector.from_values([0, 1, 2], [3, 6, 10])
+    assert result.isequal(expected)
+    assert op.binom is binary.binom
