@@ -328,7 +328,12 @@ def test_expr_is_like_scalar(s):
     }
     if s.is_cscalar:
         expected.add("_empty")
-    assert attrs - expr_attrs == expected
+    assert attrs - expr_attrs == expected, (
+        "If you see this message, you probably added a method to Scalar.  You may need to "
+        "add an entry to `scalar` set in `graphblas._automethods.py` "
+        "and then run `python -m graphblas._automethods`.  If you're messing with infix "
+        "methods, then you may need to run `python -m graphblas._infixmethods`."
+    )
     assert attrs - infix_attrs == expected
 
 
@@ -354,7 +359,12 @@ def test_index_expr_is_like_scalar(s):
     }
     if s.is_cscalar:
         expected.add("_empty")
-    assert attrs - expr_attrs == expected
+    assert attrs - expr_attrs == expected, (
+        "If you see this message, you probably added a method to Scalar.  You may need to "
+        "add an entry to `scalar` set in `graphblas._automethods.py` "
+        "and then run `python -m graphblas._automethods`.  If you're messing with infix "
+        "methods, then you may need to run `python -m graphblas._infixmethods`."
+    )
 
 
 def test_ndim(s):
