@@ -794,7 +794,7 @@ def test_reduce_agg_firstlast_index(v):
 
 def test_reduce_agg_empty():
     v = Vector("UINT8", size=3)
-    for attr, aggr in vars(agg).items():
+    for _attr, aggr in vars(agg).items():
         if not isinstance(aggr, agg.Aggregator):
             continue
         s = v.reduce(aggr).new()
@@ -1155,9 +1155,9 @@ def test_contains(v):
     assert 0 not in v
     assert 1 in v
     with pytest.raises(TypeError):
-        [0] in v
+        assert [0] in v
     with pytest.raises(TypeError):
-        (0,) in v
+        assert (0,) in v
 
 
 def test_iter(v):
@@ -1405,7 +1405,12 @@ def test_expr_is_like_vector(v):
         "resize",
         "update",
     }
-    assert attrs - expr_attrs == expected
+    assert attrs - expr_attrs == expected, (
+        "If you see this message, you probably added a method to Vector.  You may need to "
+        "add an entry to `vector` or `matrix_vector` set in `graphblas._automethods.py` "
+        "and then run `python -m graphblas._automethods`.  If you're messing with infix "
+        "methods, then you may need to run `python -m graphblas._infixmethods`."
+    )
     assert attrs - infix_attrs == expected
 
 
@@ -1434,7 +1439,12 @@ def test_index_expr_is_like_vector(v):
         "from_values",
         "resize",
     }
-    assert attrs - expr_attrs == expected
+    assert attrs - expr_attrs == expected, (
+        "If you see this message, you probably added a method to Vector.  You may need to "
+        "add an entry to `vector` or `matrix_vector` set in `graphblas._automethods.py` "
+        "and then run `python -m graphblas._automethods`.  If you're messing with infix "
+        "methods, then you may need to run `python -m graphblas._infixmethods`."
+    )
 
 
 def test_random(v):
@@ -1443,7 +1453,7 @@ def test_random(v):
     r3 = Vector.from_values([4], [2], size=v.size)
     r4 = Vector.from_values([6], [0], size=v.size)
     seen = set()
-    for i in range(1000000):  # pragma: no branch
+    for _i in range(1000000):  # pragma: no branch
         r = v.ss.selectk("random", 1)
         if r.isequal(r1):
             seen.add("r1")
@@ -1472,11 +1482,11 @@ def test_random(v):
 
 
 def test_firstk(v):
-    data = [[1, 3, 4, 6], [1, 1, 2, 0]]
+    mixed_data = [[1, 3, 4, 6], [1, 1, 2, 0]]
     iso_data = [[1, 3, 4, 6], [1, 1, 1, 1]]
     iso_v = v.dup()
     iso_v(iso_v.S) << 1
-    for w, data in [(v, data), (iso_v, iso_data)]:
+    for w, data in [(v, mixed_data), (iso_v, iso_data)]:
         for k in range(w.nvals + 1):
             x = w.ss.selectk("first", k)
             expected = Vector.from_values(data[0][:k], data[1][:k], size=w.size)
@@ -1486,11 +1496,11 @@ def test_firstk(v):
 
 
 def test_lastk(v):
-    data = [[1, 3, 4, 6], [1, 1, 2, 0]]
+    mixed_data = [[1, 3, 4, 6], [1, 1, 2, 0]]
     iso_data = [[1, 3, 4, 6], [1, 1, 1, 1]]
     iso_v = v.dup()
     iso_v(iso_v.S) << 1
-    for w, data in [(v, data), (iso_v, iso_data)]:
+    for w, data in [(v, mixed_data), (iso_v, iso_data)]:
         for k in range(w.nvals + 1):
             x = w.ss.selectk("last", k)
             expected = Vector.from_values(data[0][-k:], data[1][-k:], size=w.size)
@@ -1597,9 +1607,11 @@ def test_compactify(do_iso):
         check(v, reverse(expected), "largest", asindex=True, stop=3)
         check_reverse(v, reverse(expected), "largest", asindex=True, stop=3)
 
-    def compare(v, expected, isequal=True, **kwargs):
+    def compare(v, expected, isequal=True, sort=False, **kwargs):
         for _ in range(1000):
             w = v.ss.compactify("random", **kwargs)
+            if sort:
+                w = w.ss.compactify("smallest")
             if w.isequal(expected) == isequal:
                 break
         else:
@@ -1612,10 +1624,13 @@ def test_compactify(do_iso):
         compare(v, v.ss.compactify("first", 0, asindex=asindex), size=0, asindex=asindex)
         for i in range(1, 4):
             for how in ["first", "last", "smallest", "largest"]:
-                w = v.ss.compactify("first", i, asindex=asindex)
-                compare(v, w, size=i, asindex=asindex)
+                w = v.ss.compactify(how, i, asindex=asindex, reverse=how == "last")
+                sort = how in {"largest", "smallest"}
+                if sort:
+                    w = w.ss.compactify("smallest")
+                compare(v, w, size=i, asindex=asindex, sort=sort)
                 if not do_iso:
-                    compare(v, w, size=i, asindex=asindex, isequal=True)
+                    compare(v, w, size=i, asindex=asindex, isequal=True, sort=sort)
     with pytest.raises(ValueError):
         v.ss.compactify("bad_how")
 
@@ -1887,6 +1902,10 @@ def test_broadcasting(A, v):
     assert result.isequal(expected)
     result = binary.plus(v | A).new()
     assert result.isequal(expected)
+    # use mask
+    result(A.S, replace=True) << binary.plus(v | A)
+    expected(A.S, replace=True) << expected
+    assert result.isequal(expected)
 
     expected = semiring.any_plus(v.diag() @ A).new()
     result = v.ewise_mult(A, monoid.plus).new()
@@ -1909,6 +1928,10 @@ def test_broadcasting(A, v):
     result = A.dup()
     result += v
     assert result.isequal(expected)
+    # use mask
+    result(A.S, replace=True) << binary.plus(A | v)
+    expected(A.S, replace=True) << expected
+    assert result.isequal(expected)
 
     expected = semiring.any_plus(A @ v.diag()).new()
     result = A.ewise_mult(v, monoid.plus).new()
@@ -1954,3 +1977,54 @@ def test_ewise_union_infix():
             op(v & w, 5, left_default=10, right_default=20)
         with pytest.raises(TypeError):
             op(v, w, left_default=10, right_default=20)
+
+
+def test_reposition(v):
+    indices, values = v.to_values()
+    indices = indices.astype(int)
+
+    def get_expected(offset, size):
+        ind = indices + offset
+        mask = (ind >= 0) & (ind < size)
+        return Vector.from_values(ind[mask], values[mask], size=size)
+
+    for offset in range(-v.size - 2, v.size + 3):
+        result = v.reposition(offset).new()
+        expected = get_expected(offset, v.size)
+        assert result.isequal(expected)
+        result = v.reposition(offset, size=3).new()
+        expected = get_expected(offset, 3)
+        assert result.isequal(expected)
+        result = v.reposition(offset, size=10).new()
+        expected = get_expected(offset, 10)
+        assert result.isequal(expected)
+
+
+def test_to_values_sort():
+    # How can we get a vector to a jumbled state in SS so that export won't be sorted?
+    N = 1000000
+    a = np.unique(np.random.randint(N, size=100))
+    expected = a.copy()
+    np.random.shuffle(a)
+    v = Vector.from_values(a, a, size=N)
+    indices, values = v.to_values(sort=False)
+    v = Vector.from_values(a, a, size=N)
+    indices, values = v.to_values(sort=True)
+    assert_array_equal(indices, expected)
+    assert_array_equal(values, expected)
+
+
+def test_lambda_udfs(v):
+    result = v.apply(lambda x: x + 1).new()
+    expected = binary.plus(v, 1).new()
+    assert result.isequal(expected)
+    result = v.ewise_mult(v, lambda x, y: x + y).new()
+    expected = binary.plus(v & v).new()
+    assert result.isequal(expected)
+    result = v.ewise_add(v, lambda x, y: x + y, require_monoid=False).new()
+    assert result.isequal(expected)
+    # Should we also allow lambdas for monoids with assumed identity of 0?
+    with pytest.raises(TypeError):
+        v.ewise_add(v, lambda x, y: x + y)
+    with pytest.raises(TypeError):
+        v.inner(v, lambda x, y: x + y)
